import json

from zjun_sms_interface_sdk.sms_utils import *


class SmsSend:
    __userName = ""
    __password = ""
    __address = ""

    def __init__(self, userName: str, password: str, address: str):
        """
        构造方法，传入账号、密码、ip+端口或域名
        :param userName: 账号
        :param password: 密码
        :param address: ip+端口或域名
        """
        self.__userName = userName
        self.__password = password
        self.__address = address

    def send_sms_mass(self, phone_list: list[str], content: str, send_time: str, ext_code: str, call_data: str) -> str:
        """
        群发短信，完整参数
        :param phone_list: 手机号码列表，必填
        :param content: 短信内容， 必填
        :param send_time: 定时时间，可选，不定时传入空字符串
        :param ext_code: 扩展码，可选，可传入空字符串或None
        :param call_data: 用户回传数据，可选，可传入空字符串
        :return: json字符串
        """
        # 获取时间戳
        timestamp = get_timestamp()
        # 获取sign
        sign = generate_sign(self.__userName, self.__password, timestamp)
        # 获取url
        url = "http://" + self.__address + "/sms/api/sendMessageMass"
        # 请求数据
        data = {
            "userName": self.__userName,
            "content": content,
            "phoneList": phone_list,
            "timestamp": timestamp,
            "sign": sign,
            "sendTime": send_time,
            "extCode": ext_code,
            "callData": call_data
        }

        # 发送请求
        return send(url, json.dumps(data))

    def send_sms_one(self, message_list: list[dict[str:str]], send_time: str) -> str:
        """
        一对一短信发送
        :param message_list: 号码与内容列表，必填
        :param send_time: 定时时间，可选，可传入空字符或None
        :return: json字符串
        """
        # 获取时间戳
        timestamp = get_timestamp()
        # 获取sign
        sign = generate_sign(self.__userName, self.__password, timestamp)
        # 获取url
        url = "http://" + self.__address + "/sms/api/sendMessageOne"
        # 请求数据
        data = {
            "userName": self.__userName,
            "timestamp": timestamp,
            "sign": sign,
            "messageList": message_list,
            "sendTime": send_time,
        }

        # 发送请求
        return send(url, json.dumps(data))

    def get_report(self) -> str:
        """
        获取状态报告
        :return: json字符串
        """
        # 获取时间戳
        timestamp = get_timestamp()
        # 获取sign
        sign = generate_sign(self.__userName, self.__password, timestamp)
        # 获取url
        url = "http://" + self.__address + "/sms/api/getReport"
        # 请求数据
        data = {
            "userName": self.__userName,
            "timestamp": timestamp,
            "sign": sign,
        }

        # 发送请求
        return send(url, json.dumps(data))

    def get_upstream(self) -> str:
        """
        获取上行回复
        :return: json字符串
        """
        # 获取时间戳
        timestamp = get_timestamp()
        # 获取sign
        sign = generate_sign(self.__userName, self.__password, timestamp)
        # 获取url
        url = "http://" + self.__address + "/sms/api/getUpstream"
        # 请求数据
        data = {
            "userName": self.__userName,
            "timestamp": timestamp,
            "sign": sign,
        }

        # 发送请求
        return send(url, json.dumps(data))

    def get_balance(self) -> str:
        """
        获取余额
        :return: json字符串
        """
        # 获取时间戳
        timestamp = get_timestamp()
        # 获取sign
        sign = generate_sign(self.__userName, self.__password, timestamp)
        # 获取url
        url = "http://" + self.__address + "/sms/api/getBalance"
        # 请求数据
        data = {
            "userName": self.__userName,
            "timestamp": timestamp,
            "sign": sign,
        }

        # 发送请求
        return send(url, json.dumps(data))

    def create_template(self, content: str) -> str:
        """
        提交短信模板
        :param content: 模板内容
        :return: json字符串
        """
        # 获取时间戳
        timestamp = get_timestamp()
        # 获取sign
        sign = generate_sign(self.__userName, self.__password, timestamp)
        # 获取url
        url = "http://" + self.__address + "/sms/api/createTemplate"
        # 请求数据
        data = {
            "userName": self.__userName,
            "timestamp": timestamp,
            "sign": sign,
            "content": content
        }

        # 发送请求
        return send(url, json.dumps(data))

    def query_template(self) -> str:
        """
        查询短信模板
        :return: json字符串
        """
        # 获取时间戳
        timestamp = get_timestamp()
        # 获取sign
        sign = generate_sign(self.__userName, self.__password, timestamp)
        # 获取url
        url = "http://" + self.__address + "/sms/api/queryTemplates"
        # 请求数据
        data = {
            "userName": self.__userName,
            "timestamp": timestamp,
            "sign": sign,
        }

        # 发送请求
        return send(url, json.dumps(data))
